@@ -7,7 +7,7 @@
 # python dtr_generator.py /bin/ls /tmp/dtrtest
 #
 # If nordugrid-arc-python is installed to a non-standard location, PYTHONPATH
-# may need to be set. 
+# may need to be set.
 
 import os
 import sys
@@ -17,6 +17,7 @@ import arc
 class DTRGenerator(arc.DTRCallback):
 
     def __init__(self):
+        super(DTRGenerator, self).__init__()
         # Set up logging
         self.root_logger = arc.Logger_getRootLogger()
         self.stream = arc.LogStream(sys.stdout)
@@ -53,15 +54,15 @@ class DTRGenerator(arc.DTRCallback):
         # Since the callback is not available, wait until the transfer reaches a final state
         while dtrptr.get_status() != arc.DTRStatus.ERROR and dtrptr.get_status() != arc.DTRStatus.DONE:
             time.sleep(1)
-        print dtrptr.get_status().str()
+        sys.stdout.write("%s\n"%dtrptr.get_status().str())
 
     # This is never called in the current version
     def receiveDTR(self, dtr):
-        print 'Received back DTR', dtr.get_id()
+        sys.stdout.write('Received back DTR %s\n'%str(dtr.get_id()))
 
 def main(args):
     if len(args) != 3:
-        print "Usage: python dtr_generator.py source destination"
+        sys.stdout.write("Usage: python dtr_generator.py source destination\n")
         sys.exit(1)
     generator = DTRGenerator()
     generator.add(args[1], args[2])
