@@ -17,12 +17,12 @@ def example():
     # Get the ExecutionTargets of this ComputingElement
     retriever = arc.ComputingServiceRetriever(uc, [endpoint])
     retriever.wait()
-    targets = retriever.GetExecutionTargets()    
+    targets = retriever.GetExecutionTargets()
 
     # Shuffle the targets to simulate a random broker
     targets = list(targets)
     random.shuffle(targets)
-    
+
     # Create a JobDescription
     jobdesc = arc.JobDescription()
     jobdesc.Application.Executable.Path = "/bin/hostname"
@@ -30,23 +30,23 @@ def example():
 
     # create an empty job object which will contain our submitted job
     job = arc.Job()
-    success = False;
+    success = False
     # Submit job directly to the execution targets, without a broker
     for target in targets:
-        print "Trying to submit to", target.ComputingEndpoint.URLString, "(%s)" % target.ComputingEndpoint.InterfaceName, "...",
+        sys.stdout.write("Trying to submit to %s (%s) ... "%(target.ComputingEndpoint.URLString, target.ComputingEndpoint.InterfaceName))
         sys.stdout.flush()
         success = target.Submit(uc, jobdesc, job)
         if success:
-            print "succeeded!"
+            sys.stdout.write("succeeded!\n")
             break
         else:
-            print "failed!"
+            sys.stdout.write("failed!\n")
     if success:
-        print "Job was submitted:"
+        sys.stdout.write("Job was submitted:\n")
         job.SaveToStream(arc.CPyOstream(sys.stdout), False)
     else:
-        print "Job submission failed"
-    
+        sys.stdout.write("Job submission failed\n")
+
 # wait for all the background threads to finish before we destroy the objects they may use
 import atexit
 @atexit.register
