@@ -7,11 +7,12 @@
 #include <fcntl.h>
 #endif
 
-#include <arc/client/SubmitterPlugin.h>
+#include <arc/compute/SubmitterPlugin.h>
 
 namespace Arc {
 
   class Config;
+  class SubmissionStatus;
 
   class SubmitterPluginARC0 : public SubmitterPlugin {
   public:
@@ -22,7 +23,9 @@ namespace Arc {
 
     bool isEndpointNotSupported(const std::string& endpoint) const;
 
-    virtual bool Submit(const std::list<JobDescription>& jobdesc, const ExecutionTarget& et, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
+    virtual SubmissionStatus Submit(const std::list<JobDescription>& jobdescs, const std::string& endpoint, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
+    virtual SubmissionStatus Submit(const std::list<JobDescription>& jobdesc, const ExecutionTarget& et, EntityConsumer<Job>& jc, std::list<const JobDescription*>& notSubmitted);
+
   private:
     static Logger logger;
   };
