@@ -23,6 +23,10 @@ namespace Arc {
 
   Logger JobControllerPluginBES::logger(Logger::getRootLogger(), "JobControllerPlugin.BES");
 
+  void JobControllerPluginBES::SetUserConfig(const UserConfig& uc) {
+    JobControllerPlugin::SetUserConfig(uc);
+  }
+
   bool JobControllerPluginBES::isEndpointNotSupported(const std::string& endpoint) const {
     const std::string::size_type pos = endpoint.find("://");
     return pos != std::string::npos && lower(endpoint.substr(0, pos)) != "http" && lower(endpoint.substr(0, pos)) != "https";
@@ -30,10 +34,10 @@ namespace Arc {
 
   void JobControllerPluginBES::UpdateJobs(std::list<Job*>& jobs, std::list<std::string>& IDsProcessed, std::list<std::string>& IDsNotProcessed, bool isGrouped) const {
     MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
+    usercfg->ApplyToConfig(cfg);
 
     for (std::list<Job*>::iterator it = jobs.begin(); it != jobs.end(); ++it) {
-      AREXClient ac((*it)->JobStatusURL, cfg, usercfg.Timeout(),false);
+      AREXClient ac((*it)->JobStatusURL, cfg, usercfg->Timeout(),false);
       if (!ac.stat((*it)->IDFromEndpoint, **it)) {
         logger.msg(INFO, "Failed retrieving job status information");
         IDsNotProcessed.push_back((*it)->JobID);
@@ -53,11 +57,11 @@ namespace Arc {
 
   bool JobControllerPluginBES::CancelJobs(const std::list<Job*>& jobs, std::list<std::string>& IDsProcessed, std::list<std::string>& IDsNotProcessed, bool isGrouped) const {
     MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
+    usercfg->ApplyToConfig(cfg);
     bool ok = true;
     for (std::list<Job*>::const_iterator it = jobs.begin(); it != jobs.end(); ++it) {
       Job& job = **it;
-      AREXClient ac(job.JobManagementURL, cfg, usercfg.Timeout(), false);
+      AREXClient ac(job.JobManagementURL, cfg, usercfg->Timeout(), false);
       if (!ac.kill(job.IDFromEndpoint)) {
         ok = false;
         IDsNotProcessed.push_back(job.JobID);
@@ -87,8 +91,8 @@ namespace Arc {
 
   bool JobControllerPluginBES::GetJobDescription(const Job& job, std::string& desc_str) const {
     MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
-    AREXClient ac(job.JobManagementURL, cfg, usercfg.Timeout(), false);
+    usercfg->ApplyToConfig(cfg);
+    AREXClient ac(job.JobManagementURL, cfg, usercfg->Timeout(), false);
     if (ac.getdesc(job.IDFromEndpoint, desc_str)) {
       std::list<JobDescription> descs;
       if (JobDescription::Parse(desc_str, descs) && !descs.empty()) {
