@@ -27,6 +27,11 @@ namespace Arc {
 
   Logger SubmitterPluginARC1::logger(Logger::getRootLogger(), "SubmitterPlugin.ARC1");
 
+  void SubmitterPluginARC1::SetUserConfig(const UserConfig& uc) {
+    SubmitterPlugin::SetUserConfig(uc);
+    clients.SetUserConfig(uc);
+  }
+
   bool SubmitterPluginARC1::isEndpointNotSupported(const std::string& endpoint) const {
     const std::string::size_type pos = endpoint.find("://");
     return pos != std::string::npos && lower(endpoint.substr(0, pos)) != "http" && lower(endpoint.substr(0, pos)) != "https";
@@ -83,9 +88,12 @@ namespace Arc {
         jobid = URL((std::string)(activityIdentifier["ReferenceParameters"]["JobSessionDir"]));
         // compensate for time between request and response on slow networks
         URL sessionurl = jobid;
-        sessionurl.AddOption("threads=2",false);
+        sessionurl.AddOption("threads=3",false);
         sessionurl.AddOption("encryption=optional",false);
-        if(arex_features) sessionurl.AddOption("httpputpartial=yes",false);
+        if(arex_features) {
+          sessionurl.AddOption("httpputpartial=yes",false);
+          sessionurl.AddOption("blocksize=5242880",true);
+        }
     
         if (!PutFiles(preparedjobdesc, sessionurl)) {
           logger.msg(INFO, "Failed uploading local input files");
@@ -175,9 +183,12 @@ namespace Arc {
         jobid = URL((std::string)(activityIdentifier["ReferenceParameters"]["JobSessionDir"]));
         // compensate for time between request and response on slow networks
         URL sessionurl = jobid;
-        sessionurl.AddOption("threads=2",false);
+        sessionurl.AddOption("threads=3",false);
         sessionurl.AddOption("encryption=optional",false);
-        if(arex_features) sessionurl.AddOption("httpputpartial=yes",false);
+        if(arex_features) {
+          sessionurl.AddOption("httpputpartial=yes",false);
+          sessionurl.AddOption("blocksize=5242880",true);
+        }
     
         if (!PutFiles(preparedjobdesc, sessionurl)) {
           logger.msg(INFO, "Failed uploading local input files");
@@ -290,9 +301,10 @@ namespace Arc {
     URL newjobid((std::string)(xNewjobid["ReferenceParameters"]["JobSessionDir"]));
 
     URL sessionurl = newjobid;
-    sessionurl.AddOption("threads=2",false);
+    sessionurl.AddOption("threads=3",false);
     sessionurl.AddOption("encryption=optional",false);
     sessionurl.AddOption("httpputpartial=yes",false); // for A-REX
+    sessionurl.AddOption("blocksize=5242880",true);
 
     if (!PutFiles(preparedjobdesc, sessionurl)) {
       logger.msg(INFO, "Failed uploading local input files");
