@@ -8,8 +8,8 @@
 #include <arc/Logger.h>
 #include <arc/StringConv.h>
 #include <arc/URL.h>
-#include <arc/client/ClientInterface.h>
-#include <arc/client/JobDescription.h>
+#include <arc/communication/ClientInterface.h>
+#include <arc/compute/JobDescription.h>
 #include <arc/credential/Credential.h>
 #include <arc/message/MCC.h>
 
@@ -25,8 +25,7 @@ namespace Arc {
   Logger CREAMClient::logger(Logger::rootLogger, "CREAMClient");
 
   bool stringtoTime(const std::string& timestring, Time& time) {
-    if (timestring == "" || timestring.length() < 15)
-      return "";
+    if (timestring == "" || timestring.length() < 15) return false;
 
     //The conversion for example:
     //before: 11/5/08 11:52 PM
@@ -34,53 +33,40 @@ namespace Arc {
 
     tm timestr;
     std::string::size_type pos = 0;
-    if (sscanf(timestring.substr(pos, 8).c_str(),
-               "%2d/%2d/%2d",
-               &timestr.tm_mon,
-               &timestr.tm_mday,
-               &timestr.tm_year) == 3)
-      pos += 8;
+    if      (sscanf(timestring.substr(pos, 6).c_str(),
+                    "%d/%d/%2d",
+                    &timestr.tm_mon,
+                    &timestr.tm_mday,
+                    &timestr.tm_year) == 3) pos += 6;
     else if (sscanf(timestring.substr(pos, 7).c_str(),
                     "%2d/%d/%2d",
                     &timestr.tm_mon,
                     &timestr.tm_mday,
-                    &timestr.tm_year) == 3)
-      pos += 7;
+                    &timestr.tm_year) == 3) pos += 7;
     else if (sscanf(timestring.substr(pos, 7).c_str(),
                     "%d/%2d/%2d",
                     &timestr.tm_mon,
                     &timestr.tm_mday,
-                    &timestr.tm_year) == 3)
-      pos += 7;
-    else if (sscanf(timestring.substr(pos, 6).c_str(),
-                    "%d/%d/%2d",
+                    &timestr.tm_year) == 3) pos += 7;
+    else if (sscanf(timestring.substr(pos, 8).c_str(),
+                    "%2d/%2d/%2d",
                     &timestr.tm_mon,
                     &timestr.tm_mday,
-                    &timestr.tm_year) == 3)
-      pos += 6;
-    else
-      return false;
+                    &timestr.tm_year) == 3) pos += 8;
+    else return false;
 
     timestr.tm_year += 100;
     timestr.tm_mon--;
 
-    if (timestring[pos] == 'T' || timestring[pos] == ' ')
-      pos++;
+    if (timestring[pos] == 'T' || timestring[pos] == ' ') pos++;
 
-    if (sscanf(timestring.substr(pos, 5).c_str(),
-               "%2d:%2d",
-               &timestr.tm_hour,
-               &timestr.tm_min) == 2)
-      pos += 5;
-    else
-      return false;
+    if (sscanf(timestring.substr(pos, 5).c_str(), "%2d:%2d", &timestr.tm_hour, &timestr.tm_min) == 2) pos += 5;
+    else return false;
 
     // skip the space characters
-    while (timestring[pos] == ' ')
-      pos++;
+    while (timestring[pos] == ' ') pos++;
 
-    if (timestring.substr(pos, pos + 2) == "PM")
-      timestr.tm_hour += 12;
+    if (timestring.substr(pos, 2) == "PM") timestr.tm_hour += 12;
 
     time.SetTime(mktime(&timestr));
     return true;
@@ -96,7 +82,7 @@ namespace Arc {
                     "<id>"+id+"</id>"
                     "<creamURL>"+creamURL+"</creamURL>"+
                     (!ISB.empty() ? "<property><name>CREAMInputSandboxURI</name><value>" + ISB +"</value></property>" : std::string()) +
-                    (!ISB.empty() ? "<property><name>CREAMOutputSandboxURI</name><value>" + OSB +"</value></property>" : std::string()) +
+                    (!OSB.empty() ? "<property><name>CREAMOutputSandboxURI</name><value>" + OSB +"</value></property>" : std::string()) +
                     "<delegationID>"+delegationID+"</delegationID>"
                    "</jobId>");
   }
@@ -137,14 +123,14 @@ namespace Arc {
       delete client;
   }
 
-  bool CREAMClient::process(PayloadSOAP& req, XMLNode& response) {
+  bool CREAMClient::process(PayloadSOAP& req, XMLNode& response, const std::string& actionNS) {
     if (!client) {
       logger.msg(VERBOSE, "CREAMClient not created properly");
       return false;
     }
 
     PayloadSOAP *resp = NULL;
-    if (!client->process("http://glite.org/2007/11/ce/cream/" + action, &req, &resp)) {
+    if (!client->process(actionNS + action, &req, &resp)) {
       logger.msg(VERBOSE, "%s request failed", action);
       return false;
     }
@@ -154,10 +140,7 @@ namespace Arc {
       return false;
     }
 
-    if ((*resp)[action + "Response"]["result"])
-      (*resp)[action + "Response"]["result"].New(response);
-    else
-      (*resp)[action + "Response"].New(response);
+    (*resp)[action + "Response"].New(response);
 
     delete resp;
 
@@ -194,41 +177,41 @@ namespace Arc {
     action = "JobInfo";
 
     PayloadSOAP req(cream_ns);
-    XMLNode jobStatusRequest = req.NewChild("types:" + action). // Should not be concatenated with "Request", as in the other requests.
-                                   NewChild("types:jobId").
-                                   NewChild("types:id") = jobid;
-    if (!delegationId.empty())
-      jobStatusRequest.NewChild("types:delegationProxyId") = delegationId;
+    XMLNode xjobId = req.NewChild("types:" + action + "Request").NewChild("types:jobId");
+    xjobId.NewChild("types:id") = jobid;
+    xjobId.NewChild("types:creamURL") = client->GetURL().str();
 
     XMLNode response;
-    if (!process(req, response))
-      return false;
+    if (!process(req, response)) return false;
 
     XMLNode jobInfoNode;
-    jobInfoNode = response["jobInfo"];
+    jobInfoNode = response["result"]["jobInfo"];
 
     XMLNode lastStatusNode = jobInfoNode.Path("status").back();
 
-    if (lastStatusNode["name"])
+    if (lastStatusNode["name"]) {
       job.State = JobStateCREAM((std::string)lastStatusNode["name"]);
-
+    }
+    if (lastStatusNode["failureReason"]) {
+      job.Error.push_back((std::string)lastStatusNode["failureReason"]);
+    }
+    
     if (!job.State) {
       logger.msg(VERBOSE, "Unable to retrieve job status.");
       return false;
     }
 
-    if (ISVALID(jobInfoNode["jobId"]["id"]) && ISVALID(jobInfoNode["jobId"]["creamURL"])) {
-      job.IDFromEndpoint = URL((std::string)jobInfoNode["jobId"]["creamURL"] + "/" + (std::string)jobInfoNode["jobId"]["id"]);
+    if (ISVALID(jobInfoNode["jobId"]["id"])) {
+      job.IDFromEndpoint = (std::string)jobInfoNode["jobId"]["id"];
     }
-    if (ISVALID(jobInfoNode["jobId"]["id"]))
-      job.LocalIDFromManager = (std::string)jobInfoNode["jobId"]["id"];
     if (ISVALID(jobInfoNode["type"]))
       job.Type = (std::string)jobInfoNode["type"];
     if (ISVALID(jobInfoNode["JDL"])) {
-      job.JobDescription = (std::string)jobInfoNode["JDL"];
+      job.JobDescription = "egee:jdl";
+      job.JobDescriptionDocument = (std::string)jobInfoNode["JDL"];
 
       std::list<JobDescription> jds;
-      if (JobDescription::Parse(job.JobDescription, jds) && !jds.empty()) {
+      if (JobDescription::Parse(job.JobDescriptionDocument, jds) && !jds.empty()) {
         if (!jds.front().Application.Input.empty())
           job.StdIn = jds.front().Application.Input;
 
@@ -245,21 +228,33 @@ namespace Arc {
     }
     if (ISVALID(lastStatusNode["exitCode"]))
       job.ExitCode = stringtoi((std::string)lastStatusNode["exitCode"]);
-    if (job.State() == "DONE-FAILED")
-      job.Error.push_back((std::string)lastStatusNode["failureReason"]);
     if (ISVALID(jobInfoNode["delegationProxyInfo"])) {
+      /* Format of delegationProxyInfo node.
+      [ isRFC="<true|false>";
+        valid from="<mon>/<date>/<yy> <hour>:<min> <AM|PM> (<timezone>)";
+        valid to="<mon>/<date>/<yy> <hour>:<min> <AM|PM> (<timezone>)";
+        holder DN="<DN>";
+        holder AC issuer="<DN>";
+        VO="<VO-name>";
+        AC issuer="<DN>";
+        VOMS attributes=<VOMS-Attributes>
+      ]
+      */
+      
       std::string delegationProxy = (std::string)jobInfoNode["delegationProxyInfo"];
-      std::list<std::string> splited_proxy;
-      tokenize(delegationProxy, splited_proxy, "\n");
-      for (std::list<std::string>::iterator it = splited_proxy.begin();
-           it != splited_proxy.end(); it++) {
-        if (it->find("Holder Subject") < it->find(":"))
-          job.Owner = it->substr(it->find_first_of(":") + 1);
-        if (it->find("Valid To") < it->find(":")) {
-          Time time;
-          if (stringtoTime(it->substr(it->find_first_of(":") + 2), time) && time.GetTime() != -1)
-            job.ProxyExpirationTime = time;
-        }
+      std::size_t lBracketPos = delegationProxy.find('['), rBracketPos = delegationProxy.rfind(']');
+      if (lBracketPos != std::string::npos && rBracketPos != std::string::npos) {
+        delegationProxy = trim(delegationProxy.substr(lBracketPos, rBracketPos - lBracketPos));
+      }
+      std::list<std::string> tDelegInfo;
+      tokenize(delegationProxy, tDelegInfo, ";");
+      for (std::list<std::string>::iterator it = tDelegInfo.begin();
+           it != tDelegInfo.end(); ++it) {
+        std::list<std::string> keyValuePair;
+        tokenize(*it, keyValuePair, "=", "\"", "\"");
+        if (keyValuePair.size() != 2) continue;
+        if (lower(trim(keyValuePair.front())) == "holder dn") job.Owner = trim(keyValuePair.back(), " \"");
+        if (lower(trim(keyValuePair.front())) == "valid to")  stringtoTime(trim(keyValuePair.back(), " \""), job.ProxyExpirationTime);
       }
     }
     if (ISVALID(jobInfoNode["localUser"]))
@@ -347,11 +342,12 @@ namespace Arc {
     action = "JobCancel";
 
     PayloadSOAP req(cream_ns);
-    req.NewChild("types:J" + action + "Request").NewChild("types:jobId").NewChild("types:id") = jobid;
+    XMLNode xjobId = req.NewChild("types:" + action + "Request").NewChild("types:jobId");
+    xjobId.NewChild("types:id") = jobid;
+    xjobId.NewChild("types:creamURL") = client->GetURL().str();
 
     XMLNode response;
-    if (!process(req, response))
-      return false;
+    if (!process(req, response)) return false;
 
     if (!response) {
       logger.msg(VERBOSE, "Empty response");
@@ -367,11 +363,12 @@ namespace Arc {
     action = "JobPurge";
 
     PayloadSOAP req(cream_ns);
-    req.NewChild("types:" + action + "Request").NewChild("types:jobId").NewChild("types:id") = jobid;
+    XMLNode xjobId = req.NewChild("types:" + action + "Request").NewChild("types:jobId");
+    xjobId.NewChild("types:id") = jobid;
+    xjobId.NewChild("types:creamURL") = client->GetURL().str();
 
     XMLNode response;
-    if (!process(req, response))
-      return false;
+    if (!process(req, response)) return false;
 
     if (!response) {
       logger.msg(VERBOSE, "Empty response");
@@ -381,6 +378,73 @@ namespace Arc {
     return true;
   }
 
+  bool CREAMClient::resume(const std::string& jobid) {
+    logger.msg(VERBOSE, "Creating and sending request to resume a job");
+
+    action = "JobResume";
+
+    PayloadSOAP req(cream_ns);
+    XMLNode xjobId = req.NewChild("types:" + action + "Request").NewChild("types:jobId");
+    xjobId.NewChild("types:id") = jobid;
+    xjobId.NewChild("types:creamURL") = client->GetURL().str();
+
+    XMLNode response;
+    if (!process(req, response)) return false;
+
+    if (!response) {
+      logger.msg(VERBOSE, "Empty response");
+      return false;
+    }
+
+    return true;
+  }
+
+  bool CREAMClient::listJobs(std::list<creamJobInfo>& info) {
+    logger.msg(VERBOSE, "Creating and sending request to list jobs");
+
+    action = "JobList";
+
+    PayloadSOAP req(cream_ns);
+    req.NewChild("types:" + action + "Request");
+
+    XMLNode response;
+    if (!process(req, response)) return false;
+
+    if (!response) {
+      logger.msg(VERBOSE, "Empty response");
+      return false;
+    }
+    
+    for (XMLNode n = response["result"]; n; ++n) {
+      creamJobInfo i;
+      i = n;
+      info.push_back(i);
+    }
+
+    return true;
+  }
+
+  bool CREAMClient::getJobDesc(const std::string& jobid, std::string& desc) {
+    logger.msg(VERBOSE, "Creating and sending a status request");
+
+    action = "JobInfo";
+
+    PayloadSOAP req(cream_ns);
+    XMLNode xjobId = req.NewChild("types:" + action + "Request").NewChild("types:jobId");
+    xjobId.NewChild("types:id") = jobid;
+    xjobId.NewChild("types:creamURL") = client->GetURL().str();
+
+    XMLNode response;
+    if (!process(req, response)) return false;
+
+    if (ISVALID(response["result"]["jobInfo"]["JDL"])) {
+      desc = (std::string)response["result"]["jobInfo"]["JDL"];
+      return true;
+    }
+    
+    return false;
+  }
+
   bool CREAMClient::registerJob(const std::string& jdl_text,
                                 creamJobInfo& info) {
     logger.msg(VERBOSE, "Creating and sending job register request");
@@ -388,27 +452,26 @@ namespace Arc {
     action = "JobRegister";
 
     PayloadSOAP req(cream_ns);
-    XMLNode act_job = req.NewChild("types:" + action + "Request").NewChild("types:JobDescriptionList");
+    XMLNode act_job = req.NewChild("types:" + action + "Request").NewChild("types:jobDescriptionList");
     act_job.NewChild("types:JDL") = jdl_text;
-    act_job.NewChild("types:autoStart") = "false";
     if (!delegationId.empty())
       act_job.NewChild("types:delegationId") = delegationId;
+    act_job.NewChild("types:autoStart") = "false";
 
     XMLNode response;
-    if (!process(req, response))
-      return false;
+    if (!process(req, response)) return false;
 
     if (!response) {
       logger.msg(VERBOSE, "Empty response");
       return false;
     }
 
-    if (!response["jobId"]["id"]) {
+    if (!response["result"]["jobId"]["id"]) {
       logger.msg(VERBOSE, "No job ID in response");
       return false;
     }
 
-    info = response["jobId"];
+    info = response["result"]["jobId"];
 
     return true;
   }
@@ -420,20 +483,19 @@ namespace Arc {
 
     PayloadSOAP req(cream_ns);
     XMLNode jobStartRequest = req.NewChild("types:" + action + "Request");
-    jobStartRequest.NewChild("types:jobId").NewChild("types:id") = jobid;
-    if (!delegationId.empty())
-      jobStartRequest.NewChild("types:delegationId") = delegationId;
+    XMLNode xjobId = jobStartRequest.NewChild("types:jobId");
+    xjobId.NewChild("types:id") = jobid;
+    xjobId.NewChild("types:creamURL") = client->GetURL().str();
 
     XMLNode response;
-    if (!process(req, response))
-      return false;
+    if (!process(req, response)) return false;
 
     if (!response) {
       logger.msg(VERBOSE, "Empty response");
       return false;
     }
 
-    if (!response["jobId"]["id"]) {
+    if (!response["result"]["jobId"]["id"]) {
       logger.msg(VERBOSE, "No job ID in response");
       return false;
     }
@@ -451,8 +513,7 @@ namespace Arc {
     req.NewChild("deleg:" + action).NewChild("delegationID") = delegation_id;
 
     XMLNode response;
-    if (!process(req, response))
-      return false;
+    if (!process(req, response, "http://www.gridsite.org/namespaces/delegation-2/")) return false;
 
     std::string proxyRequestStr = (std::string)response["getProxyReqReturn"];
     if (proxyRequestStr.empty()) {
@@ -493,7 +554,7 @@ namespace Arc {
     putProxyRequest.NewChild("proxy") = signedCert;
 
     response = XMLNode();
-    if (!process(req, response))
+    if (!process(req, response, "http://www.gridsite.org/namespaces/delegation-2/"))
       return false;
 
     if (!response) {
@@ -503,24 +564,4 @@ namespace Arc {
 
     return true;
   }
-
-  bool CREAMClient::destroyDelegation(const std::string& delegation_id) {
-    logger.msg(VERBOSE, "Creating delegation");
-
-    action = "destroy";
-
-    PayloadSOAP req(cream_ns);
-    req.NewChild("deleg:" + action).NewChild("delegationID") = delegation_id;
-
-    XMLNode response;
-    if (!process(req, response))
-      return false;
-
-    if (!response) {
-      logger.msg(VERBOSE, "Empty response");
-      return false;
-    }
-
-    return true;
-  }
 } // namespace Arc
