@@ -5,7 +5,7 @@
 
 #include <list>
 
-#include <arc/client/EntityRetriever.h>
+#include <arc/compute/EntityRetriever.h>
 
 namespace Arc {
 
@@ -20,7 +20,7 @@ namespace Arc {
   public:
     TargetInformationRetrieverPluginEMIES(PluginArgument* parg):
         TargetInformationRetrieverPlugin(parg) {
-        supportedInterfaces.push_back("org.ogf.emies");
+        supportedInterfaces.push_back("org.ogf.glue.emies.resourceinfo");
     };
     ~TargetInformationRetrieverPluginEMIES() {};
 
