@@ -9,7 +9,7 @@
 #include "XRSLParser.h"
 #include "ADLParser.h"
 
-Arc::PluginDescriptor ARC_PLUGINS_TABLE_NAME[] = {
+extern Arc::PluginDescriptor const ARC_PLUGINS_TABLE_NAME[] = {
   { "ARCJSDLParser", "HED:JobDescriptionParserPlugin", "NorduGrid ARC JSDL, POSIX-JSDL, HPCP-JSDL (nordugrid:jsdl)", 0, &Arc::ARCJSDLParser::Instance },
   { "JDLParser", "HED:JobDescriptionParserPlugin", "CREAM JDL (egee:jdl)", 0, &Arc::JDLParser::Instance },
   { "XRSLParser", "HED:JobDescriptionParserPlugin", "NorduGrid xRSL (nordugrid:xrsl)", 0, &Arc::XRSLParser::Instance },
