@@ -571,30 +571,25 @@ namespace Arc {
   }
 
   JobDescriptionParserPluginResult JDLParser::Parse(const std::string& source, std::list<JobDescription>& jobdescs, const std::string& language, const std::string& dialect) const {
+    JobDescriptionParserPluginResult result(JobDescriptionParserPluginResult::WrongLanguage);
     if (language != "" && !IsLanguageSupported(language)) {
-      return false;
+      return result;
     }
 
-    logger.msg(VERBOSE, "Parsing string using JDLParser");
-
-    jobdescs.clear();
-    jobdescs.push_back(JobDescription());
-
-    JobDescription& jobdesc = jobdescs.back();
+    JobDescription parsed_jobdescription;
 
     unsigned long first = source.find_first_of("[");
     unsigned long last = source.find_last_of("]");
     if (first == std::string::npos || last == std::string::npos || first >= last) {
-      logger.msg(VERBOSE, "[JDLParser] There is at least one necessary square bracket missing or their order is incorrect. ('[' or ']')");
-      jobdescs.clear();
-      return false;
+      return result;
     }
     std::string input_text = source.substr(first + 1, last - first - 1);
 
     //Remove multiline comments
     unsigned long comment_start = 0;
-    while ((comment_start = input_text.find("/*", comment_start)) != std::string::npos)
+    while ((comment_start = input_text.find("/*", comment_start)) != std::string::npos) {
       input_text.erase(input_text.begin() + comment_start, input_text.begin() + input_text.find("*/", comment_start) + 2);
+    }
 
     std::string wcpy = "";
     std::list<std::string> lines;
@@ -619,12 +614,10 @@ namespace Arc {
 
     if (!splitJDL(wcpy, lines)) {
       logger.msg(VERBOSE, "[JDLParser] Syntax error found during the split function.");
-      jobdescs.clear();
       return false;
     }
     if (lines.size() <= 0) {
       logger.msg(VERBOSE, "[JDLParser] Lines count is zero or other funny error has occurred.");
-      jobdescs.clear();
       return false;
     }
 
@@ -633,25 +626,24 @@ namespace Arc {
       const size_t equal_pos = it->find_first_of("=");
       if (equal_pos == std::string::npos) {
         logger.msg(VERBOSE, "[JDLParser] JDL syntax error. There is at least one equals sign missing where it would be expected.");
-        jobdescs.clear();
         return false;
       }
-      if (!handleJDLattribute(trim(it->substr(0, equal_pos)), trim(it->substr(equal_pos + 1)), jobdesc)) {
-        jobdescs.clear();
+      if (!handleJDLattribute(trim(it->substr(0, equal_pos)), trim(it->substr(equal_pos + 1)), parsed_jobdescription)) {
         return false;
       }
     }
 
-    if (!ParseInputSandboxAttribute(jobdesc)) {
+    if (!ParseInputSandboxAttribute(parsed_jobdescription)) {
       return false;
     }
 
-    SourceLanguage(jobdesc) = (!language.empty() ? language : supportedLanguages.front());
-    logger.msg(INFO, "String successfully parsed as %s", jobdesc.GetSourceLanguage());
+    SourceLanguage(parsed_jobdescription) = (!language.empty() ? language : supportedLanguages.front());
+    logger.msg(VERBOSE, "String successfully parsed as %s", parsed_jobdescription.GetSourceLanguage());
+    jobdescs.push_back(parsed_jobdescription);
     return true;
   }
 
-  JobDescriptionParserPluginResult JDLParser::UnParse(const JobDescription& job, std::string& product, const std::string& language, const std::string& dialect) const {
+  JobDescriptionParserPluginResult JDLParser::Assemble(const JobDescription& job, std::string& product, const std::string& language, const std::string& dialect) const {
     if (!IsLanguageSupported(language)) {
       return false;
     }
