@@ -7,7 +7,7 @@
 #include "JobControllerPluginUNICORE.h"
 #include "SubmitterPluginUNICORE.h"
 
-Arc::PluginDescriptor ARC_PLUGINS_TABLE_NAME[] = {
+extern Arc::PluginDescriptor const ARC_PLUGINS_TABLE_NAME[] = {
   { "UNICORE", "HED:SubmitterPlugin", NULL, 0, &Arc::SubmitterPluginUNICORE::Instance },
   { "UNICORE", "HED:JobControllerPlugin", NULL, 0, &Arc::JobControllerPluginUNICORE::Instance },
   { NULL, NULL, NULL, 0, NULL }
