@@ -107,6 +107,11 @@ namespace Arc {
     return location() + G_DIR_SEPARATOR_S + PKGDATASUBDIR;
   }
 
+  std::string ArcLocation::GetLibDir() {
+    if (location().empty()) Init("");
+    return location() + G_DIR_SEPARATOR_S + PKGLIBSUBDIR;
+  }
+
   std::string ArcLocation::GetToolsDir() {
     if (location().empty()) Init("");
     return location() + G_DIR_SEPARATOR_S + PKGLIBEXECSUBDIR;
