@@ -7,6 +7,7 @@
 #include <cctype>
 #include <fstream>
 
+#include <fcntl.h>
 #include <sys/types.h>
 
 #include <arc/StringConv.h>
@@ -387,12 +388,12 @@ namespace Arc {
   }
 
   void MD5Sum::scan(const char *buf) {
-    u_char A0, A1, A2, A3, B0, B1, B2, B3, C0, C1, C2, C3, D0, D1, D2, D3;
+    unsigned A0, A1, A2, A3, B0, B1, B2, B3, C0, C1, C2, C3, D0, D1, D2, D3;
     computed = false;
     if (strncasecmp("md5:", buf, 4) != 0) return;
     int l = sscanf(buf + 4,
-                   "%02hhx%02hhx%02hhx%02hhx%02hhx%02hhx%02hhx%02hhx"
-                   "%02hhx%02hhx%02hhx%02hhx%02hhx%02hhx%02hhx%02hhx",
+                   "%02x%02x%02x%02x%02x%02x%02x%02x"
+                   "%02x%02x%02x%02x%02x%02x%02x%02x",
                    &A0, &A1, &A2, &A3, &B0, &B1, &B2, &B3,
                    &C0, &C1, &C2, &C3, &D0, &D1, &D2, &D3
                    );
@@ -548,22 +549,23 @@ namespace Arc {
   }
 
   std::string CheckSumAny::FileChecksum(const std::string& file_path, type tp, bool decimalbase) {
-    std::ifstream file(file_path.c_str(), std::ios_base::in|std::ios_base::binary|std::ios_base::ate);
-    if (!file) {
+    int h = open(file_path.c_str(), O_RDONLY);
+    if (h == -1) {
       return "";
     }
 
-    long size = file.tellg();
-    file.seekg(0, std::ios_base::beg);
-    char * buffer = new char [size];
-    file.read(buffer, size);
-    file.close();
-
     CheckSumAny csa(tp);
-    csa.start();
-    csa.add(buffer, size);
+
+    char buffer[1024];
+    ssize_t l;
+    for(;;) {
+      l = read(h, buffer, 1024);
+      if (l == -1) return "";
+      if (l == 0) break;
+      csa.add(buffer, l);
+    }
+    close(h);
     csa.end();
-    delete[] buffer;
 
     char checksum[100];
     csa.print(checksum, 100);
