@@ -24,7 +24,8 @@
 
 namespace Arc {
 
-  #define DefaultLogLevel (DEBUG)
+  static const Arc::LogLevel DefaultLogLevel = Arc::DEBUG;
+  static Arc::LogFormat DefaultLogFormat = Arc::LongFormat;
 
   static std::string list_to_domain(const std::list<std::string>& subdomains) {
     std::string domain;
@@ -229,12 +230,16 @@ namespace Arc {
   }
 
   LogDestination::LogDestination()
-    : format(LongFormat) {}
+    : format(DefaultLogFormat) {}
 
   void LogDestination::setFormat(const LogFormat& newformat) {
     format = newformat;
   }
 
+  void LogDestination::setDefaultFormat(const LogFormat& newformat) {
+    DefaultLogFormat = newformat;
+  }
+
   void LogDestination::setPrefix(const std::string& pre) {
     prefix = pre;
   }
@@ -454,14 +459,18 @@ namespace Arc {
     getContext().destinations.clear();
   }
 
-  void Logger::deleteDestinations(void) {
+  void Logger::deleteDestinations(LogDestination* exclude) {
     Glib::Mutex::Lock lock(mutex);
     std::list<LogDestination*>& destinations = getContext().destinations;
     for(std::list<LogDestination*>::iterator dest = destinations.begin();
                             dest != destinations.end();) {
-      delete *dest;
-      *dest = NULL;
-      dest = destinations.erase(dest);
+      if (*dest != exclude) {
+        delete *dest;
+        *dest = NULL;
+        dest = destinations.erase(dest);
+      } else {
+        ++dest;
+      }
     }
   }
 
