@@ -570,11 +570,13 @@ namespace Arc {
      **/
     std::string NetworkInfo;
     
+    /// Specifies amount of requested RAM in MB
     /**
      * \mapdefattr IndividualPhysicalMemory Arc::ResourcesType
      **/
     Range<int> IndividualPhysicalMemory;
     
+    /// Specifies amount of requested virtual memory in MB
     /**
      * \mapdefattr IndividualVirtualMemory Arc::ResourcesType
      **/
@@ -793,6 +795,8 @@ namespace Arc {
     std::list<InputFileType> InputFiles;
     /// List of outputfiles
     std::list<OutputFileType> OutputFiles;
+    /// Delegation for all data staging operations
+    std::string DelegationID;
   };
 
 
