@@ -153,6 +153,27 @@ namespace Arc {
     }
   }
 
+  void JobSupervisor::Select(const JobSelector& selector) {
+    processed.clear();
+    notprocessed.clear();
+
+    for (JobSelectionMap::iterator it = jcJobMap.begin();
+         it != jcJobMap.end(); ++it) {
+      for (std::list<Job*>::iterator itJ = it->second.first.begin();
+           itJ != it->second.first.end();) {
+        if (!selector.Select(**itJ)) {
+          notprocessed.push_back((*itJ)->JobID);
+          it->second.second.push_back(*itJ);
+          itJ = it->second.first.erase(itJ);
+        }
+        else {
+          processed.push_back((*itJ)->JobID);
+          ++itJ;
+        }
+      }
+    }
+  }
+
   void JobSupervisor::ClearSelection() {
     for (JobSelectionMap::iterator it = jcJobMap.begin();
          it != jcJobMap.end(); ++it) {
