@@ -1647,8 +1647,7 @@ err:
 
     PKCS8_PRIV_KEY_INFO *p8inf = NULL;
     if (pkey) {
-      int p8_broken = PKCS8_OK;
-      if (!(p8inf = EVP_PKEY2PKCS8_broken(pkey, p8_broken))) {
+      if (!(p8inf = EVP_PKEY2PKCS8(pkey))) {
         NSSUtilLogger.msg(ERROR, "Failed to convert EVP_PKEY to PKCS8");
         EVP_PKEY_free(pkey);
         return false;
@@ -2771,7 +2770,7 @@ loser:
     random_cn = rand();
     char* CN_name = NULL;
     CN_name = (char*)malloc(sizeof(long)*4 + 1);
-    snprintf(CN_name, sizeof(long)*4 + 1, "%ld", random_cn);
+    snprintf(CN_name, sizeof(long)*4 + 1, "%lu", random_cn);
     std::string str = "CN="; str.append(CN_name); str.append(",");
     subname_str.insert(0, str.c_str(), str.length());
     NSSUtilLogger.msg(DEBUG, "Proxy subject: %s", subname_str.c_str());
