@@ -5,21 +5,36 @@
 
 namespace Arc {
 
+/** \addtogroup credential
+ *  @{ */
+
+/// Obtain password from some source
+/**
+ * Pure virtual class meant to be extended with a specific mechanism to obtain
+ * password.
+ * \since Added in 4.0.0.
+ **/
 class PasswordSource {
  public:
   typedef enum {
-    NO_PASSWORD = 0, // No password is returned. Authoritative. Not same as empty password.
-    PASSWORD = 1,     // Password is  provided. Authoritative.
-    CANCEL = 2       // Request to cancel procedure which need password.
+    /// No password is returned. Authoritative. Not same as empty password.
+    NO_PASSWORD = 0,
+    /// Password is  provided. Authoritative.
+    PASSWORD = 1,
+    /// Request to cancel procedure which need password.
+    CANCEL = 2
   } Result;
   virtual Result Get(std::string& password, int minsize, int maxsize) = 0;
+  virtual ~PasswordSource(void) { };
 };
 
+/// No password
 class PasswordSourceNone: public PasswordSource {
  public:
   virtual Result Get(std::string& password, int minsize, int maxsize);
 };
 
+/// Obtain password from a string
 class PasswordSourceString: public PasswordSource {
  private:
   std::string password_;
@@ -28,6 +43,7 @@ class PasswordSourceString: public PasswordSource {
   virtual Result Get(std::string& password, int minsize, int maxsize);
 };
 
+/// Obtain password from stream
 class PasswordSourceStream: public PasswordSource {
  private:
   std::istream* password_;
@@ -36,6 +52,7 @@ class PasswordSourceStream: public PasswordSource {
   virtual Result Get(std::string& password, int minsize, int maxsize);
 };
 
+/// Obtain password through OpenSSL user interface
 class PasswordSourceInteractive: public PasswordSource {
  private:
   std::string prompt_;
@@ -45,6 +62,8 @@ class PasswordSourceInteractive: public PasswordSource {
   virtual Result Get(std::string& password, int minsize, int maxsize);
 };
 
+/** @} */
+
 } // namespace Arc
 
 #endif // __ARC_PASSWORD_SOURCE_H__
