@@ -12,6 +12,7 @@
 #include <arc/Thread.h>
 #include <arc/Utils.h>
 
+#include "GlobusErrorUtils.h"
 #include "GlobusWorkarounds.h"
 
 namespace Arc {
@@ -19,7 +20,6 @@ namespace Arc {
   static Glib::Mutex lock_;
 
   bool GlobusRecoverProxyOpenSSL(void) {
-#ifdef HAVE_OPENSSL_PROXY
     // No harm even if not needed - shall trun proxies on for code 
     // which was written with no proxies in mind
     SetEnv("OPENSSL_ALLOW_PROXY_CERTS","1");
@@ -71,22 +71,19 @@ namespace Arc {
     return false;
 #endif // OPENSSL_VERSION_NUMBER > 0x0090804f
 */
-#else  // HAVE_OPENSSL_PROXY
-    return true;
-#endif // HAVE_OPENSSL_PROXY
   }
 
   bool GlobusPrepareGSSAPI(void) {
     Glib::Mutex::Lock lock(lock_);
     int index = -1;
-    globus_gsi_callback_get_X509_STORE_callback_data_index(&index);
-    globus_gsi_callback_get_SSL_callback_data_index(&index);
+    GlobusResult(globus_gsi_callback_get_X509_STORE_callback_data_index(&index));
+    GlobusResult(globus_gsi_callback_get_SSL_callback_data_index(&index));
     return true;
   }
 
   bool GlobusModuleActivate(globus_module_descriptor_t* module) {
     Glib::Mutex::Lock lock(lock_);
-    return (globus_module_activate(module) == GLOBUS_SUCCESS);
+    return (GlobusResult(globus_module_activate(module)));
   }
 }
 
