@@ -12,18 +12,33 @@ namespace Arc {
 
   Logger MCC::logger(Logger::getRootLogger(), "MCC");
 
+  MCCInterface::MCCInterface(PluginArgument* arg):Plugin(arg) {
+  }
+
+  MCCInterface::~MCCInterface() {
+  }
+
+  MCC::~MCC() {
+  }
+
+  MCC::MCC(Config *, PluginArgument* arg):MCCInterface(arg) {
+  }
+
   void MCC::Next(MCCInterface *next, const std::string& label) {
+    Glib::Mutex::Lock lock(next_lock_);
     if (next == NULL) next_.erase(label);
     else next_[label] = next;
   }
 
   MCCInterface *MCC::Next(const std::string& label) {
+    Glib::Mutex::Lock lock(next_lock_);
     std::map<std::string, MCCInterface *>::iterator n = next_.find(label);
     if (n == next_.end()) return NULL;
     return n->second;
   }
 
   void MCC::Unlink() {
+    Glib::Mutex::Lock lock(next_lock_);
     next_.clear();
   }
 
@@ -99,7 +114,7 @@ namespace Arc {
           //}
         }
       }
-      catch (Glib::FileError) {}
+      catch (Glib::FileError&) {}
     }
     return mm;
   }
